@@ -109,6 +109,9 @@ new_CppObject_xp <- function(module, pointer, ...) {
 	.External( class__newInstance, module, pointer, ... )
 }
 
+new_dummyObject <- function(...)
+    .External( "class__dummyInstance", ...)
+
 
 # class method for $initialize
 cpp_object_initializer <- function(.self, .refClassDef, ...){
@@ -123,6 +126,18 @@ cpp_object_initializer <- function(.self, .refClassDef, ...){
     .self
 }
 
+cpp_object_dummy <- function(.self, .refClassDef) {
+    selfEnv <- as.environment(.self)
+    ## like initializer but a dummy for the case of no default
+    ## constructor.  Will throw an error if the object is used.
+    fields <- .refClassDef@fieldPrototypes
+    pointer <- new_dummyObject()
+    assign(".module", fields$.module, envir = selfEnv)
+    assign(".pointer", pointer, envir = selfEnv)
+    assign(".cppclass", fields$.pointer, envir = selfEnv)
+    .self
+}    
+
 Module <- function( module, PACKAGE = getPackageName(where), where = topenv(parent.frame()), mustStart = FALSE ) {
     if(is(module, "Module")) {
         xp <- .getModulePointer(module, FALSE)
@@ -196,7 +211,7 @@ Module <- function( module, PACKAGE = getPackageName(where), where = topenv(pare
               else
                  function(...) {
                      if(nargs())  Rcpp:::cpp_object_initializer(.self,.refClassDef, ...)
-                     else .self
+                     else Rcpp:::cpp_object_dummy(.self, .refClassDef)
                  }
                           )
                
@@ -229,7 +244,9 @@ Module <- function( module, PACKAGE = getPackageName(where), where = topenv(pare
             
         }
     }
-    module$refClassGenerators <- generators
+    if(length(classes)) {
+        module$refClassGenerators <- generators
+    }
     
     for( i in seq_along(classes) ){
         clname <- as.character(classes[[i]])
