@@ -15,14 +15,16 @@
 # You should have received a copy of the GNU General Public License
 # along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
+.dummyInstancePointer <- new.env() # just something permanent
+
 .onLoad <- function(libname, pkgname){
-    install_help_workaround()
     .Call("init_Rcpp_cache", PACKAGE = "Rcpp" )
     minimum_svn_rev <- packageDescription( pkgname )[["MinimumSvnRev"]]
-    if( as.integer(R.version[["svn rev"]]) < as.integer(minimum_svn_rev)){
-        packageStartupMessage(gettextf(paste("R version (%s) older than minimum required (%s)",
-                                             "for full use of reference methods"),
-                                       R.version[["svn rev"]], minimum_svn_rev))
-    }
+    # if( as.integer(R.version[["svn rev"]]) < as.integer(minimum_svn_rev)){
+    #     packageStartupMessage(gettextf(paste("R version (%s) older than minimum required (%s)",
+    #                                          "for full use of reference methods"),
+    #                                    R.version[["svn rev"]], minimum_svn_rev))
+    # }
+    new_dummyObject(.dummyInstancePointer);
 }
 
