@@ -38,7 +38,7 @@ class CppFunction {
 		virtual ~CppFunction(){} ;
 		virtual int nargs(){ return 0 ; }
 		virtual bool is_void(){ return false ; }
-		virtual const char* signature(const char* ){ return "" ; }
+		virtual void signature(std::string&, const char* ){}
 		virtual SEXP get_formals(){ return R_NilValue; }
 		
 		std::string docstring ;
@@ -57,8 +57,8 @@ public:
 	    name(name_), docstring( doc == 0 ? "" : doc ){} ;
 	
 	virtual Rcpp::List fields(SEXP){ return Rcpp::List(0); }
-	virtual Rcpp::List getMethods(SEXP){ return Rcpp::List(0); }
-	virtual Rcpp::List getConstructors(SEXP){ return Rcpp::List(0); }
+	virtual Rcpp::List getMethods(SEXP, std::string&){ return Rcpp::List(0); }
+	virtual Rcpp::List getConstructors(SEXP, std::string&){ return Rcpp::List(0); }
 	
 	virtual void run_finalizer(SEXP){ }
 	
@@ -168,7 +168,7 @@ class CppMethod {
 		virtual int nargs(){ return 0 ; }
 		virtual bool is_void(){ return false ; }
 		virtual bool is_const(){ return false ; }
-		virtual const char* signature(const char* name ){ return name ; }
+		virtual void signature(std::string& s, const char* name ){ s = name ; }
 } ;
 
 #include <Rcpp/module/Module_generated_ctor_signature.h>
@@ -193,8 +193,8 @@ public:
     std::string docstring ;
     
     inline int nargs(){ return ctor->nargs() ; }
-    inline const char* signature(const std::string& class_name){ 
-        return ctor->signature(class_name) ;
+    inline void signature(std::string& buffer, const std::string& class_name){ 
+        ctor->signature(buffer, class_name) ;
     }
 } ;
 
@@ -211,19 +211,21 @@ public:
     inline int nargs(){ return method->nargs() ; }
     inline bool is_void(){ return method->is_void() ; }
     inline bool is_const(){ return method->is_const() ; }
-    inline const char* signature(const char* name){ return method->signature(name); }
+    inline void signature(std::string& s, const char* name){ 
+        method->signature(s, name);
+    }
 
 } ;
 
 template <typename Class>
 class S4_CppConstructor : public Rcpp::Reference {
 public:             
-    S4_CppConstructor( SignedConstructor<Class>* m, SEXP class_xp, const std::string& class_name ) : Reference( "C++Constructor" ){
+    S4_CppConstructor( SignedConstructor<Class>* m, SEXP class_xp, const std::string& class_name, std::string& buffer ) : Reference( "C++Constructor" ){
         field( "pointer" )       = Rcpp::XPtr< SignedConstructor<Class> >( m, false ) ;
         field( "class_pointer" ) = class_xp ;
         field( "nargs" )         = m->nargs() ;
-        std::string sign(  m->signature(class_name) ) ;
-        field( "signature" )     = sign ;
+        m->signature( buffer, class_name ) ;
+        field( "signature" )     = buffer ;
         field( "docstring" )     = m->docstring ;
     }
 } ;
@@ -234,18 +236,19 @@ public:
     typedef SignedMethod<Class> signed_method_class ;
 	typedef std::vector<signed_method_class*> vec_signed_method ;
 	
-	S4_CppOverloadedMethods( vec_signed_method* m, SEXP class_xp, const char* name ) : Reference( "C++OverloadedMethods" ){
+	S4_CppOverloadedMethods( vec_signed_method* m, SEXP class_xp, const char* name, std::string& buffer ) : Reference( "C++OverloadedMethods" ){
         
 	    int n = m->size() ;
-        Rcpp::LogicalVector voidness( n), constness(n) ;
-        Rcpp::CharacterVector docstrings( n ), signatures(n) ;
+        Rcpp::LogicalVector voidness(n), constness(n) ;
+        Rcpp::CharacterVector docstrings(n), signatures(n) ;
         signed_method_class* met ;
         for( int i=0; i<n; i++){ 
             met = m->at(i) ;
             voidness[i] = met->is_void() ;
             constness[i] = met->is_const() ;
             docstrings[i] = met->docstring ;
-            signatures[i] = met->signature(name) ;
+            met->signature(buffer, name) ;
+            signatures[i] = buffer ;
         }
         
 	    field( "pointer" )       = Rcpp::XPtr< vec_signed_method >( m, false ) ;
@@ -646,7 +649,7 @@ public:
 		return out ;
 	}
 
-	Rcpp::List getMethods( SEXP class_xp ){
+	Rcpp::List getMethods( SEXP class_xp, std::string& buffer){
 	    int n = vec_methods.size() ;
 		Rcpp::CharacterVector mnames(n) ;
 		Rcpp::List res(n) ;
@@ -655,18 +658,18 @@ public:
 	    for( int i=0; i<n; i++, ++it){
 		    mnames[i] = it->first ;
 		    v = it->second ;
-		    res[i] = S4_CppOverloadedMethods<Class>( v , class_xp, it->first.c_str() ) ;
+		    res[i] = S4_CppOverloadedMethods<Class>( v , class_xp, it->first.c_str(), buffer ) ;
 		}
 		res.names() = mnames ;
 	    return res ;
 	}
 	
-	Rcpp::List getConstructors( SEXP class_xp){
+	Rcpp::List getConstructors( SEXP class_xp, std::string& buffer){
 	    int n = constructors.size() ;
 		Rcpp::List out(n) ;
 		typename vec_signed_constructor::iterator it = constructors.begin( ) ;
 		for( int i=0; i<n; i++, ++it){
-			out[i] = S4_CppConstructor<Class>( *it , class_xp, name ) ; 
+			out[i] = S4_CppConstructor<Class>( *it , class_xp, name, buffer ) ; 
 		} 
 		return out ;
 	}
@@ -711,7 +714,7 @@ class_<Class>* class_<Class>::singleton ;
 class CppClass : public S4{
 public:
 	typedef Rcpp::XPtr<Rcpp::Module> XP ;
-	CppClass( Module* p, class_Base* clazz ) ;
+	CppClass( Module* p, class_Base* clazz, std::string& ) ;
 	CppClass( SEXP x) ;
 } ;
 
@@ -723,6 +726,7 @@ public:
 
 }
 
+#define RCPP_MODULE_BOOT(name) _rcpp_module_boot_##name
 
 #define RCPP_MODULE(name)                                            \
 void _rcpp_module_##name##_init() ;                                  \
